Database

Struct Database 

pub struct Database { /* private fields */ }
Decrypted password database

See the module-level documentation for more information.

Implementations

Source

impl Database

pub fn meta(&self) -> &Meta

Return meta information about the database like name and access times

pub fn meta_mut(&mut self) -> &mut Meta

Mutable meta information about the database like name and access times

pub fn name(&self) -> &str

Get the database name

pub fn set_name<S: ToString>(&mut self, name: S)

Set the database name

pub fn description(&self) -> &str

Get the database description

pub fn set_description<S: ToString>(&mut self, desc: S)

Set the database name

pub fn add_entry(&mut self, entry: Entry)

Add a entry to the root group

pub fn add_group(&mut self, entry: Group)

Add a child group to the root group

pub fn replace_root(&mut self, group: Group)

Replace the root group (and therefore all entries!) with a custom tree

pub fn find_group<F: FnMut(&Group) -> bool>(&self, f: F) -> Option<&Group>

Recursively searches for the first group matching a filter

pub fn find_group_mut<F: FnMut(&Group) -> bool>( &mut self, f: F, ) -> Option<&mut Group>

Recursively searches for the first group matching a filter, returns it mutably

pub fn find_entry<F: FnMut(&Entry) -> bool>(&self, f: F) -> Option<&Entry>

Recursively searches for the first entry matching a filter

pub fn find_entry_mut<F: FnMut(&Entry) -> bool>( &mut self, f: F, ) -> Option<&mut Entry>

Recursively searches for the first entry matching a filter, returns it mutably

pub fn root(&self) -> &Group

Top level group for database entries

pub fn root_mut(&mut self) -> &mut Group

Mutable top level group for database entries