Entry

Struct Entry 

pub struct Entry { /* private fields */ }
A single password entry

Implementations

Source

impl Entry

pub fn add_field(&mut self, field: Field)

Add a new field to the entry

pub fn remove_field(&mut self, key: &str)

Remove a field by its key

If there are duplicate fields, removes them all

pub fn new_version(&mut self)

Generate a new version of this entry, pushing the current state to history

pub fn fields(&self) -> impl Iterator<Item = &Field>

Iterate through all the fields

pub fn fields_mut(&mut self) -> impl Iterator<Item = &mut Field>

Iterate through all the field mutably

pub fn history(&self) -> &History

Iterate through all the fields

pub fn history_mut(&mut self) -> &mut History

Iterate through all the field mutably

pub fn find(&self, key: &str) -> Option<&Field>

Find a field in this entry with a given key

pub fn find_mut(&mut self, key: &str) -> Option<&mut Field>

Find a field in this entry with a given key

pub fn times(&self) -> &Times

Audit times for this entry

pub fn times_mut(&mut self) -> &mut Times

Mutable audit times for this entry

pub fn uuid(&self) -> Uuid

Set the identifier for this item

pub fn set_uuid(&mut self, uuid: Uuid)

Get the identifier for this item

pub fn title(&self) -> Option<&str>

Return the title of this item

pub fn set_title<S: ToString>(&mut self, title: S)

Set the title of this entry

pub fn username(&self) -> Option<&str>

Return the username of this item

pub fn set_username<S: ToString>(&mut self, username: S)

Set the username of this entry

pub fn url(&self) -> Option<&str>

Return the URL of this item

pub fn set_url<S: ToString>(&mut self, url: S)

Set the URL of this entry

pub fn otp(&self) -> Option<Otp<'_>>

Return the TOTP of this item, as stored by KeepassXC

pub fn set_otp(&mut self, otp: Otp<'_>)

Return the TOTP of this item, as stored by KeepassXC

pub fn password(&self) -> Option<&str>

Return the password of this item

pub fn set_password<S: ToString>(&mut self, password: S)

Set the password of this entry