pub struct Field { /* private fields */ }Expand description
A key value pair
Implementations
Sourceimpl Field
impl Field
Sourcepub fn new_protected(key: &str, value: &str) -> Field
pub fn new_protected(key: &str, value: &str) -> Field
Create a new field without memory protection
Sourcepub fn protected(&self) -> bool
pub fn protected(&self) -> bool
Get whether memory protection and extra encryption should be applied
Note: This is instructional for official clients, this library does not support memory protection
Sourcepub fn set_protected(&mut self, protected: bool)
pub fn set_protected(&mut self, protected: bool)
Set whether memory protection and extra encryption should be applied
Note: This is instructional for official clients, this library does not support memory protection