Group

Struct Group 

pub struct Group { /* private fields */ }
A group or folder of password entries and child groups

Implementations

Source

impl Group

pub fn new<S: ToString>(name: S) -> Group

Create a new group with the given name

pub fn uuid(&self) -> Uuid

Identifier for this group

pub fn set_uuid(&mut self, uuid: Uuid)

Set identifier for this group

pub fn name(&self) -> &str

Display name for this group

pub fn set_name<S: ToString>(&mut self, name: S)

Set display name for this group

pub fn add_entry(&mut self, entry: Entry)

Add a new entry to this group

pub fn remove_entry(&mut self, uuid: Uuid) -> Option<Entry>

Remove an entry by its UUID

This is a no-op if the no direct child of this group has the given UUID

pub fn add_group(&mut self, group: Group)

Add a new child group to this group

pub fn remove_group(&mut self, uuid: Uuid) -> Option<Group>

Remove an child group by its UUID

This is a no-op if the no direct child of this group has the given UUID

pub fn groups(&self) -> impl Iterator<Item = &Group>

Iterate through all the direct child groups of this group

pub fn groups_mut(&mut self) -> impl Iterator<Item = &mut Group>

Iterate mutably through all the direct child groups of this group

pub fn group_count(&self) -> usize

Count of direct child groups of this group

pub fn entry_count(&self) -> usize

Count of direct entries of this group

pub fn entries(&self) -> impl Iterator<Item = &Entry>

Iterate through all the direct entries of this group

pub fn entries_mut(&mut self) -> impl Iterator<Item = &mut Entry>

Iterate mutably through all the direct entries of this group

pub fn recursive_entries<'a>(&'a self) -> Box<dyn Iterator<Item = &Entry> + 'a>

Iterator through all entries in this group or children

pub fn recursive_entries_mut<'a>( &'a mut self, ) -> Box<dyn Iterator<Item = &mut Entry> + 'a>

Mutable Iterator through all entries in this group or children

pub fn recursive_groups<'a>(&'a self) -> Box<dyn Iterator<Item = &Group> + 'a>

Iterator through all child groups of this group

pub fn find_group<F: FnMut(&Group) -> bool>(&self, f: F) -> Option<&Group>

Find a group in this group’s children or it’s children’s children

pub fn find_group_mut<F: FnMut(&Group) -> bool>( &mut self, f: F, ) -> Option<&mut Group>

Find a mutable group in this group’s children or it’s children’s children

pub fn find_entry<F: FnMut(&Entry) -> bool>(&self, f: F) -> Option<&Entry>

Find a entry in this group’s children or it’s children’s children

pub fn find_entry_mut<F: FnMut(&Entry) -> bool>( &mut self, f: F, ) -> Option<&mut Entry>

Find a mutable entry in this group’s children or it’s children’s children

pub fn times(&self) -> &Times

Audit times for this group

pub fn times_mut(&mut self) -> &mut Times

Mutable audit times for this group