pub struct Database { /* private fields */ }Expand description
Decrypted password database
See the module-level documentation for more information.
Implementations
Sourceimpl Database
impl Database
Sourcepub fn meta(&self) -> &Meta
pub fn meta(&self) -> &Meta
Return meta information about the database like name and access times
Sourcepub fn meta_mut(&mut self) -> &mut Meta
pub fn meta_mut(&mut self) -> &mut Meta
Mutable meta information about the database like name and access times
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Get the database description
Sourcepub fn set_description<S: ToString>(&mut self, desc: S)
pub fn set_description<S: ToString>(&mut self, desc: S)
Set the database name
Sourcepub fn replace_root(&mut self, group: Group)
pub fn replace_root(&mut self, group: Group)
Replace the root group (and therefore all entries!) with a custom tree
Sourcepub fn find_group<F: FnMut(&Group) -> bool>(&self, f: F) -> Option<&Group>
pub fn find_group<F: FnMut(&Group) -> bool>(&self, f: F) -> Option<&Group>
Recursively searches for the first group matching a filter
Sourcepub fn find_group_mut<F: FnMut(&Group) -> bool>(
&mut self,
f: F,
) -> Option<&mut Group>
pub fn find_group_mut<F: FnMut(&Group) -> bool>( &mut self, f: F, ) -> Option<&mut Group>
Recursively searches for the first group matching a filter, returns it mutably
Sourcepub fn find_entry<F: FnMut(&Entry) -> bool>(&self, f: F) -> Option<&Entry>
pub fn find_entry<F: FnMut(&Entry) -> bool>(&self, f: F) -> Option<&Entry>
Recursively searches for the first entry matching a filter