pub struct Group { /* private fields */ }Expand description
A group or folder of password entries and child groups
Implementations
Sourceimpl Group
impl Group
Sourcepub fn remove_entry(&mut self, uuid: Uuid) -> Option<Entry>
pub fn remove_entry(&mut self, uuid: Uuid) -> Option<Entry>
Remove an entry by its UUID
This is a no-op if the no direct child of this group has the given UUID
Sourcepub fn remove_group(&mut self, uuid: Uuid) -> Option<Group>
pub fn remove_group(&mut self, uuid: Uuid) -> Option<Group>
Remove an child group by its UUID
This is a no-op if the no direct child of this group has the given UUID
Sourcepub fn groups(&self) -> impl Iterator<Item = &Group>
pub fn groups(&self) -> impl Iterator<Item = &Group>
Iterate through all the direct child groups of this group
Sourcepub fn groups_mut(&mut self) -> impl Iterator<Item = &mut Group>
pub fn groups_mut(&mut self) -> impl Iterator<Item = &mut Group>
Iterate mutably through all the direct child groups of this group
Sourcepub fn group_count(&self) -> usize
pub fn group_count(&self) -> usize
Count of direct child groups of this group
Sourcepub fn entry_count(&self) -> usize
pub fn entry_count(&self) -> usize
Count of direct entries of this group
Sourcepub fn entries(&self) -> impl Iterator<Item = &Entry>
pub fn entries(&self) -> impl Iterator<Item = &Entry>
Iterate through all the direct entries of this group
Sourcepub fn entries_mut(&mut self) -> impl Iterator<Item = &mut Entry>
pub fn entries_mut(&mut self) -> impl Iterator<Item = &mut Entry>
Iterate mutably through all the direct entries of this group
Sourcepub fn recursive_entries<'a>(&'a self) -> Box<dyn Iterator<Item = &Entry> + 'a>
pub fn recursive_entries<'a>(&'a self) -> Box<dyn Iterator<Item = &Entry> + 'a>
Iterator through all entries in this group or children
Sourcepub fn recursive_entries_mut<'a>(
&'a mut self,
) -> Box<dyn Iterator<Item = &mut Entry> + 'a>
pub fn recursive_entries_mut<'a>( &'a mut self, ) -> Box<dyn Iterator<Item = &mut Entry> + 'a>
Mutable Iterator through all entries in this group or children
Sourcepub fn recursive_groups<'a>(&'a self) -> Box<dyn Iterator<Item = &Group> + 'a>
pub fn recursive_groups<'a>(&'a self) -> Box<dyn Iterator<Item = &Group> + 'a>
Iterator through all child groups of this group
Sourcepub fn find_group<F: FnMut(&Group) -> bool>(&self, f: F) -> Option<&Group>
pub fn find_group<F: FnMut(&Group) -> bool>(&self, f: F) -> Option<&Group>
Find a group in this group’s children or it’s children’s children
Sourcepub fn find_group_mut<F: FnMut(&Group) -> bool>(
&mut self,
f: F,
) -> Option<&mut Group>
pub fn find_group_mut<F: FnMut(&Group) -> bool>( &mut self, f: F, ) -> Option<&mut Group>
Find a mutable group in this group’s children or it’s children’s children
Sourcepub fn find_entry<F: FnMut(&Entry) -> bool>(&self, f: F) -> Option<&Entry>
pub fn find_entry<F: FnMut(&Entry) -> bool>(&self, f: F) -> Option<&Entry>
Find a entry in this group’s children or it’s children’s children